# Metadata for the widget EGG. Should leave it for the (unimplemented) widget
# tracker to track it

__DISTRIBUTION__ = 'tw.timeline'
__DESCRIPTION__ = 'Timeline Widget application'
__URL__ = ''
__VERSION__ = '0.1a0'
__AUTHOR__ = 'Christopher Perkins'
__EMAIL__ = 'chris@percious.com'
__COPYRIGHT__ = "Copyright 2008 Christopher Perkins"
__LICENSE__ = 'MIT'
